BatchMetrics

Struct BatchMetrics 

pub struct BatchMetrics { /* private fields */ }
Shared metric definitions registered on a Prometheus Registry.

Create once, then call recorder for each Batcher instance. All metrics use a batcher label to distinguish between instances.

Metric types are Clone-cheap (Arc-backed internally), so cloning this struct is inexpensive.

Implementations

Source

impl BatchMetrics

pub fn new(registry: &Registry) -> Result<Self>

Register metrics on registry with the default prefix (batch).

pub fn with_prefix(registry: &Registry, prefix: &str) -> Result<Self>

Register metrics on registry with a custom prefix.

Metric names follow the pattern {prefix}_{metric_name}.

pub fn recorder(&self, batcher_name: &str) -> BatchMetricsRecorder

Create a BatchMetricsRecorder for a specific batcher instance.

The batcher_name is used as the value for the batcher label on all metrics.