pub struct BatchMetrics { /* private fields */ }Expand description
Implementations
Sourceimpl BatchMetrics
impl BatchMetrics
Sourcepub fn new(registry: &Registry) -> Result<Self>
pub fn new(registry: &Registry) -> Result<Self>
Register metrics on registry with the default prefix (batch).
Sourcepub fn with_prefix(registry: &Registry, prefix: &str) -> Result<Self>
pub fn with_prefix(registry: &Registry, prefix: &str) -> Result<Self>
Register metrics on registry with a custom prefix.
Metric names follow the pattern {prefix}_{metric_name}.
Sourcepub fn recorder(&self, batcher_name: &str) -> BatchMetricsRecorder
pub fn recorder(&self, batcher_name: &str) -> BatchMetricsRecorder
Create a BatchMetricsRecorder for a specific batcher instance.
The batcher_name is used as the value for the batcher label on all metrics.